@@ -38,7 +38,7 @@ def module_name(pytestconfig):
 def connector_class():
     """ This takes in the connector file name and tries to import it """
     try:
-        path = os.path.abspath(os.path.join(os.path.dirname(__file__), "..\\..\\..\\..\\"))
+        path = os.path.abspath(os.path.join(os.path.dirname(__file__), r"..\\..\\..\\..\\"))
         print(path)
         if not path in sys.path:
             sys.path.insert(1, path)
